#
# spec file for package plexus-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           plexus-utils
Version:        4.0.2
Release:        1.3
Summary:        Plexus Common Utilities
License:        Apache-1.1 AND Apache-2.0 AND xpp AND BSD-3-Clause AND SUSE-Public-Domain
Group:          Development/Libraries/Java
URL:            https://codehaus-plexus.github.io/plexus-utils/
Source0:        https://github.com/codehaus-plexus/%{name}/archive/%{name}-%{version}.tar.gz
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  plexus-xml
BuildArch:      noarch

%description
Plexus contains end-to-end developer tools for writing applications.
At the core is the container, which can be embedded or for an
application server. There are many reusable components for hibernate,
form processing, jndi, i18n, velocity, etc. Plexus also includes an
application server which is like a J2EE application server.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
Javadoc for %{name}.

%prep
%setup -q -n %{name}-%{name}-%{version}

cp %{SOURCE1} build.xml
mkdir -p lib
build-jar-repository -s lib plexus/xml

%build
%{ant} jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/plexus
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/plexus/utils.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/plexus
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/plexus/utils.pom
%add_maven_depmap plexus/utils.pom plexus/utils.jar -a plexus:plexus-utils
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%doc README.md
%license NOTICE.txt LICENSE.txt

%files javadoc
%{_javadocdir}/%{name}
%license NOTICE.txt LICENSE.txt

%changelog
* Fri Oct  4 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upsteam version 4.0.2
  * Bug Fixes
    + Specify /D for cmd.exe to bypass the Command Processor
    Autorun folder
  * Dependency updates
    + Bump org.codehaus.plexus:plexus from 17 to 18
    + Bump org.codehaus.plexus:plexus-xml from 3.0.0 to 3.0.1
* Tue Apr 30 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 4.0.1
  * New features and improvements
    + Add .gitignore to default excludes
    + downgrade plexus-xml from 4 to 3: keep Maven 3 compatibility
* Fri Apr  5 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 4.0.0
  * Starting with version 4, XML classes (in
    org.codehaus.plexus.util.xml and
    org.codehaus.plexus.util.xml.pull) have been extracted to a
    separate plexus-xml: if you need them, just use this new
    artifact.
  * Other changes:
    + Fix false difference detected with
    CachingOutputStream/CachingWriter when streams are flushed
    + Dependency updates
    + Switch to junit 5
* Wed May  3 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream vesion 3.5.1
  * Changes
    + Reading and writing files using Java NIO (#232)
    + Partial revert of "Support combine.self='remove'" to fix
    MNG-7709 (#241)
    + Fix reading comments with UTF chars (fixes #238) (#240)
* Tue Oct 25 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.5.0
  * Changes of 3.5.0
    + Don't throw IOException when none is required
    + Always preserve dominant node value (even if empty)
    + Don't overwrite blank (but non-empty) dominant values during
    mergeXpp3Dom
    + Deprecate isEmpty(String) and isNotEmpty(String) in favour of
    same named
    + isEmpty(String) must not return false for whitespace-only
    values
    + Get rid maven-plugin-testing-harness from dependency
  * Changes of 3.4.2
    + Provides a CachingOuptutStream and a CachingWriter
    + Use (already) precalculated value
    + use github shared actions
    + MXParser fixes
    + Fix last modified time not being updated on linux
    + Fix regression and deprecate: FileUtils.fileAppend should
    create file
    + Fix some testing XML files checkout with incorrect eol
    + Fixed regressions: #163 and #194
    + Don't ignore valid SCM files
  * Change of 3.4.1
    + Fixes #163: Regression: encoding error when parsing a
    ISO-8859-1 xml
* Wed May 11 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.3.1
  * Fix: Don't ignore valid SCM files
  * the latest version supporting Java 8 still
* Wed Mar 23 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Thu Nov 21 2019 Fridrich Strba <fstrba@suse.com>
- Upgrade to upstream version 3.3.0
- Removed patch:
  * 0001-Follow-symlinks-in-NioFiles.copy.patch
    + not needed with this version
* Tue Apr  9 2019 Fridrich Strba <fstrba@suse.com>
- Remove reference to the parent pom since we are not building
  using Maven.
* Sun Mar  3 2019 Jan Engelhardt <jengelh@inai.de>
- Describe package, not project.
* Sat Mar  2 2019 Fridrich Strba <fstrba@suse.com>
- Initial package for plexus-utils 3.1.1
- Generate and customize ant build file
